class ZipRemoteSource {
    constructor( url, localPath) {
        this.FS = window.FS;
        this.url = url;
        this.id = new Date().getTime();

        this.localPath = localPath;

        this.originUrl = this.url;
        this.isDir = false;
        this.prefixPath = "/veclip/";  
        this.localFilePaths = []; // 用于存储
        this.refCount = 1; // 被引用的次数
        this.isLoading = false;
        this.isLoaded = false;
        this.tryCount = 3;
    }


    extname(filename) {
        if (!filename || typeof filename != 'string') {
            return "";
        };
        let a = filename.split('').reverse().join('');
        let b = a.substring(0, a.search(/\./)).split('').reverse().join('');
        return b
    };

    get(url){
        return new Promise((resolve) => {
            var xhr = new XMLHttpRequest()
            xhr.open('GET', url, true);
            xhr.responseType = "arraybuffer"
            xhr.onreadystatechange = function () {
                if (this.readyState === 4) {
                    if (this.status === 200) {
                        resolve({status : true, response : this.response});
                    } else {
                        resolve({status : false, response : this.response});
                    }
                }
            }
            xhr.send();
        });
    }


    // 加载资源
    load() {
        if (this.isLoading || this.isLoaded || !this.tryCount) {
            return;
        }
        this.isLoading = true;

        let isExist = this.isExistFilePath(this.prefixPath);
        if (!isExist) this.mkdirInToMemory(this.prefixPath);

        let fullPath = this.prefixPath + this.id + "." + this.extname(this.url);
        if (this.extname(this.url) == "") {
            console.warn("invalid source " + fullPath + ":" + this.url);
            this.isLoading = false;
            return;
        }

        // 远程加载的文件
        return new Promise((resovle) => {
            this.get(this.url).then( ret => {
                this.loadNetworkResourceZip(ret.response)
                    .then(ret => {
                        this.isLoaded = true;
                        this.isLoading = false;
                        resovle(ret);
                });
            });
        });
        
    }

    /**
     * 加载文件
     * @param  url :string;
        *网络资源路径
     * @param  filePath :string;
        *内存文件路径 
    */
    loadFile(data, filePath, status) {
        
        if (status != 0) {
            console.error(`loading status ${filePath} : ${status}` );
        }
        if (status != 0) {
            this.isLoaded = false;
            this.isLoading = false;
            this.tryCount--;
            return;
        }

        let isExist = this.isExistFilePath(filePath);
        if (isExist) return;

        let ret = this.loadDataIntoMemory(filePath, data);
        if (ret.status) {
            this.localPath = filePath;
            this.isLoaded = true;
            this.isLoading = false;
        } else {
            console.err("FS write file error :" + this.localPath + ", " + this.url);
        }
    }

    /**
     * 加载Zip包
     * @param url : string;
        *网络地址        
    */
    loadNetworkResourceZip(data) {
        let _this = this;
        return new Promise((resolve, reject) => {
            let statusObj = { msg: "", status: true };
            JSZip
                .loadAsync(data)
                .then(async zipData => {
                    let fielAjaxArr = [];
                    let filePathList = [];
                    let fileList = zipData.files;
                    // this.localPath = `${this.prefixPath}effect/${this.id}/`;
                    
                    statusObj.path = _this.localPath;
                    for (const key in fileList) {
                        let file = fileList[key];
                        let fullPath = `${this.localPath}${key}`;
                        if (file.dir) {
                            this.mkdirInToMemory(fullPath);
                            this.localFilePaths.push(fullPath);
                            console.log(`创建文件夹:  ${fullPath}`);
                        } else {
                            let fielAjax = file.async("uint8array");
                            fielAjaxArr.push(fielAjax);
                            filePathList.push(fullPath);
                            console.log(`创建文件:  ${fullPath}`);
                        }
                    }
                    Promise
                        .all(fielAjaxArr)
                        .then(res => {
                            let count = 0;
                            for (const key in filePathList) {
                                const path = filePathList[key];
                                const data = res[count++];
                                let status = this.loadDataIntoMemory(path, data);
                                if (!status.status) {
                                    statusObj.msg = status.msg;
                                    statusObj.status = false;
                                    return reject(statusObj);
                                }
                                this.localFilePaths.push(path);
                            }
                            _this.isLoading = false;
                            _this.isLoaded = true;
                            resolve(statusObj);
                        }).catch(err => {
                            statusObj.msg = err.message;
                            statusObj.status = false;
                            reject(statusObj);
                        });
                }).catch(err => {
                    statusObj.msg = err.message;
                    statusObj.status = false;
                    reject(statusObj);
                });
        });
    }


    /**
     *  向内存中写入文件
     * @param filePath: string;
        *   内存路径
     * @param data
        *  ArrayBuffer对象
     * @return statusObj 
         * msg : stirng;
         * status : boolean;
    */
    loadDataIntoMemory(filePath, data) {
        let FS = this.FS;
        let statusObj = {
            msg: "",
            status: true
        };
        if (!filePath || !data) {
            statusObj.msg = "文件路径或数据不存在!";
            statusObj.status = false;
            return statusObj;
        }
        try {
            let uint8Data = new Uint8Array(data);
            FS.writeFile(filePath, uint8Data);
        } catch (err) {
            statusObj.msg = err.message;
            statusObj.status = false;
        }
        return statusObj;
    }


    /**
     * 判断内存文件是否存在
     * @param  filePath 
    */
    isExistFilePath(filePath) {
        let FS = this.FS;
        try {
            FS.stat(filePath);
            return true;
        } catch (error) {
            return false;
        }
    }

    /**
      * 清除当前source对象,写入内存的资源
      * @param  fileList:<string>Array
      *  当前的localFilePaths数组
   */
    clear(fileList) {
        let FS = this.FS;
        fileList = fileList.reverse();
        for (const key in fileList) {
            const path = fileList[key];
            let isExist = this.isExistFilePath(path);
            if (!isExist) continue;
            let fileInfo = FS.stat(path);
            if (FS.isFile(fileInfo.mode)) {
                FS.unlink(path);
            }
            if (FS.isDir(fileInfo.mode)) {
                FS.rmdir(path);
            }
            // console.log(path);
        }
        this.localFilePaths = [];
    }

    /**
      *  创建内存文件夹
          * @param filePath : string;    
    */
    mkdirInToMemory(dirPath) {
        let FS = this.FS;
        let arrpaths = dirPath.split('/');
        if (arrpaths.length === 0) {
            return;
        }
        let targetPath = "";
        for (let j = 0; j < arrpaths.length - 1; j++) {
            if (arrpaths[j] === "") continue;
            targetPath = targetPath + "/" + arrpaths[j];
            try {
                FS.stat(targetPath);
            } catch (err) {
                FS.mkdir(targetPath, 0o777);
            };
        }
    }


    unload() {
        this.isLoaded = false;
        this.isLoading = false;
        this.refCount = 0;
        // this.id = "source-" + uuid(); // reset source id
        let isExist = this.isExistFilePath(this.localPath);
        if (!isExist) {
            return;
        } 
        let path = this.localPath;
        let fileInfo = FS.stat(path);
        if (FS.isFile(fileInfo.mode)) {
            console.log("remove : " + path);
            FS.unlink(path);
        }
        if (FS.isDir(fileInfo.mode)) {
            this.clear(this.localFilePaths);
            console.log("remove : " + path);
        }
        // this.localPath = "";
        // this.localFilePaths = [];

    }

    isLoading() {
        return this.isLoading;
    }

    isLoaded() {
        return this.isLoaded;
    }

    getLocalPath() {
        return this.localPath;
    }

    // 增加引用
    ref() {
        this.refCount++;
    }

    // 减少引用
    unref() {
        this.refCount--;
        if (this.refCount <= 0) {
            this.unload();
        }
    }
}
