# 特效相关接口


# SXEffect
特效基类

### 方法

#### getEffectId() : string
```
   /**
     * 效果的唯一id
     * @return uuid
     */
```

#### getType() : SXEffectType
```
    /**
     * 效果类型
     * @return  效果类型
     */
```

#### isValid() : bool
```
   /**
     * 效果是否有效
     * @note 无资源或资源错误会导致效果不可用
     * @return
     */
```

#### setDuration(time : number)  : void
```
    /**
     * 设置时长，时间跟随方式为kFollowWholeProcess时无效
     * @param time 秒
     */
```

#### getDuration() : number
```
    /**
     * 效果的持续时长，时间跟随方式为kFollowWholeProcess时无效
     * @return 时长，单位为秒
     */
```

#### setStartTime(startTime : number) : void
```
    /**
     * 设置开始时间
     * 不同时间跟随方式start time的参照时间是不一样的，跟随方式祥见SXEffectTimeFollowType类型说明
     * kFollowStart：效果开始时间为相对于轨道开始时间的局部时间
     * kFollowDisplayTime: 效果开始时间为相对于轨道开始显示时间的局部时间
     * kFollowEnd: 效果开始时间为相对于轨道结束时间的局部时间，并且时间方向为反向
     * kFollowWholeProcess：无效，效果于轨道显示时间一致，同时开始同时结束
     * @param time 开始时间是相对与轨道in point的时间
     */
```

#### getStartTime() : number
```
    /**
     * 不同时间跟随方式start time的参照时间是不一样的，跟随方式祥见SXEffectTimeFollowType类型说明
     * kFollowStart：效果开始时间为相对于轨道开始时间的局部时间
     * kFollowDisplayTime: 效果开始时间为相对于轨道开始显示时间的局部时间
     * kFollowEnd: 效果开始时间为相对于轨道结束时间的局部时间，并且时间方向为反向
     * kFollowWholeProcess：无效，效果于轨道显示时间一致，同时开始同时结束
     * @return 秒
     */
```


#### setFollowType(type : SXEffectTimeFollowType) : void
```
    /**
     * 设置此效果是跟随轨道时间方式，默认为跟随轨道开始显示时间即kFollowDisplayTime
     * @param type 跟随轨道时间方式
     */
```

#### getFollowType() : SXEffectTimeFollowType 
```
    /**
     * 获取效果跟随轨道时间方式
     * @note 例如跟随轨道开始时间与轨道一同开始、跟随轨道的结束时间与轨道一同结束等，默认跟随方式为kFollowDisplayTime
     * @return 跟随轨道时间方式
     */
```

#### setExtendType(type : SXEffectTimeExtendType) : void
```
    /**
     * 设置效果在显示时间区间内的扩展方式
     * @note 扩展方式决定当特效时间超出特效自身的时长时如何扩展
     * @note 默认扩展方式为kStretch
     * @param type 扩展类型
     */
```

#### getExtendType() : SXEffectTimeExtendType 
```
    /**
     * 获取特效的时间扩展方式
     * @note 扩展方式决定当特效时间超出特效自身的时长时如何扩展，默认扩展方式为kStretch
     * @return 扩展方式
     */
```

#### setSpeed(speed : number) : void
```
    /**
     * 设置特效倍速，默认为1倍速
     * @warning 仅扩展方式为kStretchAndLoop时有效
     * @param speed 倍速
     */
```
#### getSpeed() : number
```
    /**
     * 获取倍速
     * @warning 仅扩展方式为kStretchAndLoop时有效
     * @return 倍速
     */
```

#### setDurationOfOneCycle(duration : number)
```
    /**
     * 设置一次循环的时长，时长会转化为倍速，因此未设置动画资源时此设置无效
     * @warning 仅扩展方式为kStretchAndLoop时有效
     * @param duration 一次循环的时长
     */
```

#### getDurationOfOneCycle() : void
```
    /**
     * 获取一次循环的时长，时长由倍速转化，因此未设置动画资源时返回值为0
     * @warning 仅扩展方式为kStretchAndLoop时有效
     * @return 一次循环的时长
     */
```
#### getResource() : SXResource
```
    /**
     * 获取资源数据
     * @return 资源对象
     */
```



---

## SXFilterEffect

```
滤镜特效，继承 SXEffect
```

### 方法

#### setAlpha(alpha : number) : void
```
    /**
     * 设置滤镜的不透明度
     * @param alpha 滤镜的不透明度，区间为【0，1】
     */
```

#### getAlpha() : number
```
    /**
     * 获取滤镜的不透明度
     * @return 区间为【0，1】的不透明度
     */
```

#### setResource(resource : SXResource) : bool
```
   /**
     * 设置滤镜资源
     * @param resource 资源包
     * @return 是否替换成功
     */
```

---

## SXVideoEffect

```
视频特效，继承 SXEffect
```

### 方法

#### setResource(resource : SXResource) : bool
```
    /**
     * 设置视频特效资源
     * @param resource 资源包
     * @return 是否替换成功
     */
```

---

## SXTrackAnimationEffect

```
轨道动画，继承 SXEffect
```

### 方法

#### setResource(resource : SXResource) : bool
```
    /**
     * 设置轨道动画资源
     * @param resource 资源包
     * @return 是否替换成功
     */
```

---

## SXAnimationEffect

```
视频动画，继承 SXEffect
```

### 方法

#### setResource(resource : SXResource) : bool

```
    /**
     * 设置轨道动画资源
     * @param resource 资源包
     * @return 是否替换成功
     */
```

---

## SXTextAnimationEffect

```
文字动画，继承 SXEffect
```


---

## SXGenericEffectType

```
内置特效类型

kColorAdjustment    色调调节特效
kChromaKey          抠图特效
kFaceBeauty         美颜特效
kFastBlur           快速模糊


# 参数列表

# kColorAdjustment 色调调节参数列表

brightness          亮度, 值类型: float, 值范围: [0, 1]
contrast            对比度, 值类型: float, 值范围: [-1, 1]
saturation          饱和度, 值类型: float, 值范围: [-1, 1]
sharpen             锐化, 值类型: float, 值范围: [-1, 1]
highlight           高亮, 值类型: float, 值范围: [0, 1]
shadow              阴影, 值类型: float, 值范围: [0, 1]
exposure            曝光度, 值类型: float, 值范围: [-1, 1]
hue                 色相, 值类型: float, 值范围: [0, 1]



# kChromaKey  抠图特效参数列表

color               抠图颜色, 值类型: String, 值范围: 十六进制颜色字符串: #00FF00
similarity          相似度, 值类型: float, 值范围: [0, 1]  
smoothness          平滑度, 值类型: float, 值范围: [0, 1]
spill_reduce        溢色消除, 值类型: float, 值范围: [0, 1]
edge_thin           边缘缩进, 值类型: int, 值范围: [0, 100]
edge_feather        边缘羽化, 类型: int, 值范围: [0, 50]


# kFastBlur 快速模糊特效参数列表

strength            模糊力度, 值类型: int, 范围: [0,8], 默认值: 2, 0与1效果相同
radius              模糊半径, 值类型: float, 范围: [0, 60], 默认值: 8, 尽量增大模糊力度,减小模糊半径

```


## SXGenericEffect

```
内置特效
```

### 方法

#### setAttributeFloat(name : string, value : number) : bool
```
    /**
     * setAttribute()函数的float类型特例
     * @param name 属性名称
     * @param value 属性值
     * @return 是否设置成功，名称错误会导致设置失败
     */
```

#### setAttributeString(name : string, value : string) : bool
```
    /**
     * setAttribute()函数的String类型特例
     * @param name 属性名称
     * @param value 属性值
     * @return 是否设置成功，名称错误会导致设置失败
     */
```

#### setAttributeColor(name : string, color : string) : bool
```
    /**
     * setAttribute()函数的color类型特例
     * @param name 属性名称
     * @param value 颜色的十六进制字符串
     * @return 是否设置成功，名称错误会导致设置失败
     */
```

#### resetAttributes() : void

```
    /**
     * 重置特效属性
     */
```

####  getGenericEffectType() : SXGenericEffectType

```
    /**
     * 获取内置特效的类型
     * @return 内置特效类型
     */
```
