# SXTrackGroup

轨道组, 用于管理轨道


## 接口

---
#### getGroupId() : string
```
/**
* 轨道唯一id
* @return uuid
*/
```

---
#### getDuration(excludeAudio : bool) : number
```
/**
* 获取组中轨道的最大结束时间(单位: 秒)
* @param excludeAudio true表示排除音频，不计算音频时长
* @return 轨道的最大结束时间
*/
```

---
#### arrangeTracks(process_transition : bool) : void

```
/*
* 按开始显示时间首尾相接顺序排列轨道，音频轨道除外
*
* @note 重排轨道会引起轨道显示时间区间及轨道顺序的变化，轨道顺序会按显示时间重新排序
* @note process_transition为true时前一个轨道有转场时，轨道将自动交叉到转场开始处，
* 后一个轨道时长不足转场时长时，交叉时长为后一个轨道时长
*
* @param process_transition 是否处理转场交叉
*/
```

---
#### addTrack(track : SXTrack, display_time : number) : bool
```
/**
* start time  display time      duration   disappear time  end time
*    |             |               |             |            |
*    |             |-----------------------------|            |
*    |-------------|-----------------------------|------------|
* ----------------------------------------------------------------------
*                 time
* 在组的某个时间添加一个轨道，如已加入此组或添加到非创建此轨道的合成中返回false
* @note 轨道只能添加到创建此轨道的合成中，如果轨道已在另一个组中会自动将轨道从另一个组中移除
* 轨道在组中的顺序决定了轨道的渲染顺序
* @param track
* @param display_time 轨道的开始显示时间，等价于调用轨道方法 moveToTime
* @return 添加成功返回true，失败返回false
*/
```

---
#### removeTrack(track_id : string) : void
```
/**
* 从组中移除一个轨道
* @note 仅从 group 中移除,不会释放 track
* 
* @param track_id 轨道唯一id
* @return 如组内有此轨道返回true，无此轨道返回false
*/
```

---
#### moveTrackTo(track_id : string, time : number ) : bool
```
/**
* 修改轨道顺序
* @param track_id 轨道唯一id
* @param index 轨道索引，0表示添加到第一个，小于0或者大于轨道总数的索引会将轨道添加到末尾
* @note 轨道在组中的顺序决定了轨道的渲染顺序
* @return 查找轨道失败返回false，否则返回true
*/
```

---
#### splitTrack(track_id : string, time : number) : SXTrack
```
/**
* display time   track     split time     new track    out point
*   |-----------------------|--------------------------|
* ----------------------------------------------------------------------
* 拆分轨道，拆分后的轨道附加效果时间不变，请根据需要做相应的调整
* @note 拆分后的新轨道会自动插入到被拆分轨道的下一个位置
* @param track_id 轨道唯一id
* @param time 相对于轨道自身display time的局部时间
* @return 查找轨道失败或拆分时间不在轨道显示范围内返回false，否则返回true
*/
```

---
#### clearTracks() : void
```
/**
* 清空组内所有轨道
*/
```

---
#### getTrack(track_id : string) : SXTrack
```
/**
* 通过id查找组内的轨道
* @param track_id 轨道唯一id
* @return 查找成功返回轨道实例对象，否则返回nullptr
*/
```
